
From: Dominik Brodowski <linux@dominikbrodowski.de>

Remove the no longer used "name" parameter from alloc_io_space, 
find_{io,mem}_region.

Signed-off-by: Dominik Brodowski <linux@brodo.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/pcmcia/cistpl.c      |    3 +--
 25-akpm/drivers/pcmcia/cs.c          |   13 +++++--------
 25-akpm/drivers/pcmcia/cs_internal.h |    4 ++--
 25-akpm/drivers/pcmcia/rsrc_mgr.c    |    4 ++--
 4 files changed, 10 insertions(+), 14 deletions(-)

diff -puN drivers/pcmcia/cistpl.c~pcmcia-remove-unneeded-parameter-from-rsrc_mgr drivers/pcmcia/cistpl.c
--- 25/drivers/pcmcia/cistpl.c~pcmcia-remove-unneeded-parameter-from-rsrc_mgr	Fri Dec 17 15:25:02 2004
+++ 25-akpm/drivers/pcmcia/cistpl.c	Fri Dec 17 15:25:02 2004
@@ -89,8 +89,7 @@ set_cis_map(struct pcmcia_socket *s, uns
 {
     pccard_mem_map *mem = &s->cis_mem;
     if (!(s->features & SS_CAP_STATIC_MAP) && mem->res == NULL) {
-	mem->res = find_mem_region(0, s->map_size, s->map_size, 0,
-				   "card services", s);
+	mem->res = find_mem_region(0, s->map_size, s->map_size, 0, s);
 	if (mem->res == NULL) {
 	    printk(KERN_NOTICE "cs: unable to map card memory!\n");
 	    return NULL;
diff -puN drivers/pcmcia/cs.c~pcmcia-remove-unneeded-parameter-from-rsrc_mgr drivers/pcmcia/cs.c
--- 25/drivers/pcmcia/cs.c~pcmcia-remove-unneeded-parameter-from-rsrc_mgr	Fri Dec 17 15:25:02 2004
+++ 25-akpm/drivers/pcmcia/cs.c	Fri Dec 17 15:25:02 2004
@@ -742,7 +742,7 @@ void pcmcia_parse_events(struct pcmcia_s
 ======================================================================*/
 
 static int alloc_io_space(struct pcmcia_socket *s, u_int attr, ioaddr_t *base,
-			  ioaddr_t num, u_int lines, char *name)
+			  ioaddr_t num, u_int lines)
 {
     int i;
     ioaddr_t try, align;
@@ -774,7 +774,7 @@ static int alloc_io_space(struct pcmcia_
 	    return 1;
     for (i = 0; i < MAX_IO_WIN; i++) {
 	if (s->io[i].NumPorts == 0) {
-	    s->io[i].res = find_io_region(*base, num, align, name, s);
+	    s->io[i].res = find_io_region(*base, num, align, s);
 	    if (s->io[i].res) {
 		s->io[i].Attributes = attr;
 		s->io[i].BasePort = *base = s->io[i].res->start;
@@ -1497,14 +1497,12 @@ int pcmcia_request_io(client_handle_t ha
 	return CS_BAD_ATTRIBUTE;
 
     if (alloc_io_space(s, req->Attributes1, &req->BasePort1,
-		       req->NumPorts1, req->IOAddrLines,
-		       handle->dev_info))
+		       req->NumPorts1, req->IOAddrLines))
 	return CS_IN_USE;
 
     if (req->NumPorts2) {
 	if (alloc_io_space(s, req->Attributes2, &req->BasePort2,
-			   req->NumPorts2, req->IOAddrLines,
-			   handle->dev_info)) {
+			   req->NumPorts2, req->IOAddrLines)) {
 	    release_io_space(s, req->BasePort1, req->NumPorts1);
 	    return CS_IN_USE;
 	}
@@ -1644,8 +1642,7 @@ int pcmcia_request_window(client_handle_
 
     if (!(s->features & SS_CAP_STATIC_MAP)) {
 	win->ctl.res = find_mem_region(req->Base, req->Size, align,
-				       (req->Attributes & WIN_MAP_BELOW_1MB),
-				       (*handle)->dev_info, s);
+				       (req->Attributes & WIN_MAP_BELOW_1MB), s);
 	if (!win->ctl.res)
 	    return CS_IN_USE;
     }
diff -puN drivers/pcmcia/cs_internal.h~pcmcia-remove-unneeded-parameter-from-rsrc_mgr drivers/pcmcia/cs_internal.h
--- 25/drivers/pcmcia/cs_internal.h~pcmcia-remove-unneeded-parameter-from-rsrc_mgr	Fri Dec 17 15:25:02 2004
+++ 25-akpm/drivers/pcmcia/cs_internal.h	Fri Dec 17 15:25:02 2004
@@ -135,11 +135,11 @@ int pccard_read_tuple(struct pcmcia_sock
 /* In rsrc_mgr */
 void pcmcia_validate_mem(struct pcmcia_socket *s);
 struct resource *find_io_region(unsigned long base, int num, unsigned long align,
-		   char *name, struct pcmcia_socket *s);
+		   struct pcmcia_socket *s);
 int adjust_io_region(struct resource *res, unsigned long r_start,
 		     unsigned long r_end, struct pcmcia_socket *s);
 struct resource *find_mem_region(u_long base, u_long num, u_long align,
-		    int low, char *name, struct pcmcia_socket *s);
+		    int low, struct pcmcia_socket *s);
 int try_irq(u_int Attributes, int irq, int specific);
 void undo_irq(u_int Attributes, int irq);
 int adjust_resource_info(client_handle_t handle, adjust_t *adj);
diff -puN drivers/pcmcia/rsrc_mgr.c~pcmcia-remove-unneeded-parameter-from-rsrc_mgr drivers/pcmcia/rsrc_mgr.c
--- 25/drivers/pcmcia/rsrc_mgr.c~pcmcia-remove-unneeded-parameter-from-rsrc_mgr	Fri Dec 17 15:25:02 2004
+++ 25-akpm/drivers/pcmcia/rsrc_mgr.c	Fri Dec 17 15:25:02 2004
@@ -620,7 +620,7 @@ int adjust_io_region(struct resource *re
 ======================================================================*/
 
 struct resource *find_io_region(unsigned long base, int num,
-		   unsigned long align, char *name, struct pcmcia_socket *s)
+		   unsigned long align, struct pcmcia_socket *s)
 {
 	struct resource *res = make_resource(0, num, IORESOURCE_IO, s->dev.class_id);
 	struct pcmcia_align_data data;
@@ -653,7 +653,7 @@ struct resource *find_io_region(unsigned
 }
 
 struct resource *find_mem_region(u_long base, u_long num, u_long align,
-				 int low, char *name, struct pcmcia_socket *s)
+				 int low, struct pcmcia_socket *s)
 {
 	struct resource *res = make_resource(0, num, IORESOURCE_MEM, s->dev.class_id);
 	struct pcmcia_align_data data;
_
